@@ -6,22 +6,17 @@ import compas
 import compas_rhino
 
 from compas.geometry import add_vectors
-from compas.geometry import dot_vectors
 from compas.geometry import scale_vector
 from compas.geometry import subtract_vectors
 from compas.geometry import normalize_vector
-from compas.geometry import midpoint_point_point
 
-from compas.utilities import i_to_rgb
 from compas.utilities import i_to_green
 from compas.utilities import color_to_colordict
 
 from compas_rhino.utilities import delete_objects
-from compas_rhino.utilities import draw_labels
 
 from compas_3gs.algorithms import volmesh_ud
 
-from compas_3gs.utilities import pair_hf_to_uv
 from compas_3gs.utilities import pair_uv_to_hf
 
 from compas_3gs.utilities import get_index_colordict
@@ -47,22 +42,16 @@ try:
     from Rhino.DocObjects.ObjectColorSource import ColorFromObject
     from Rhino.DocObjects.ObjectDecoration import EndArrowhead
 
-    find_object            = sc.doc.Objects.Find
+    find_object = sc.doc.Objects.Find
     find_layer_by_fullpath = sc.doc.Layers.FindByFullPath
-    add_arc                = sc.doc.Objects.AddArc
-    add_brep               = sc.doc.Objects.AddBrep
-    add_curve              = sc.doc.Objects.AddCurve
+    add_arc = sc.doc.Objects.AddArc
+    add_brep = sc.doc.Objects.AddBrep
+    add_curve = sc.doc.Objects.AddCurve
 
 except ImportError:
     compas.raise_if_ironpython()
 
 
-__author__    = 'Juney Lee'
-__copyright__ = 'Copyright 2019, BLOCK Research Group - ETH Zurich'
-__license__   = 'MIT License'
-__email__     = 'juney.lee@arch.ethz.ch'
-
-
 __all__ = ['draw_vertex_normal',
            'draw_vertex_fixities',
 
@@ -103,30 +92,30 @@ def draw_vertex_normal(datastructure, vkeys=None):
 
 def draw_vertex_fixities(diagram):
 
-    text_dict  = {}
+    text_dict = {}
     color_dict = {}
-    for vkey in diagram.vertices():
+    for vertex in diagram.vertices():
 
-        text  = ''
+        text = ''
         r = 0
         g = 0
         b = 0
-        if diagram.vertex[vkey]['x_fix']:
+        if diagram.vertex_attribute(vertex, 'x_fix') is True:
             text += 'x'
             r = 255
-        if diagram.vertex[vkey]['y_fix']:
+        if diagram.vertex_attribute(vertex, 'y_fix') is True:
             text += 'y'
             g = 255
-        if diagram.vertex[vkey]['z_fix']:
+        if diagram.vertex_attribute(vertex, 'z_fix') is True:
             text += 'z'
             b = 255
 
         if text != '':
-            text_dict[vkey]  = text
-            color_dict[vkey] = (r, g, b)
+            text_dict[vertex] = text
+            color_dict[vertex] = (r, g, b)
 
     diagram.draw()
-    diagram.draw_vertex_labels(text=text_dict, color=color_dict)
+    diagram.draw_vertexlabels(text=text_dict, color=color_dict)
 
 
 # ******************************************************************************
@@ -176,17 +165,17 @@ def draw_cell_force_vectors(volmesh, ckey):
     """Draw the force vectors of a single cell.
     """
     center = volmesh.cell_centroid(ckey)
-    lines  = []
+    lines = []
 
     for hfkey in volmesh.halfface:
-        normal = volmesh.halfface_oriented_normal(hfkey, unitized=False)
+        normal = volmesh.halfface_normal(hfkey, unitized=False)
 
         lines.append({
             'start': center,
-            'end'  : add_vectors(center, normal),
+            'end': add_vectors(center, normal),
             'arrow': 'end',
             'color': (0, 255, 0),
-            'name' : 'hfkey.{}'.format(hfkey)})
+            'name': 'hfkey.{}'.format(hfkey)})
 
     compas_rhino.draw_lines(lines)
 
@@ -227,10 +216,10 @@ def draw_cell_labels(volmesh, ckeys=None, text=None, color=None):
     labels = []
     for ckey in textdict:
         labels.append({
-            'pos'  : volmesh.cell_centroid(ckey),
-            'name' : '{0}.cell.label.{1}'.format(volmesh.name, ckey),
+            'pos': volmesh.cell_centroid(ckey),
+            'name': '{0}.cell.label.{1}'.format(volmesh.name, ckey),
             'color': colordict[ckey],
-            'text' : textdict[ckey]})
+            'text': textdict[ckey]})
 
     # 4. draw ------------------------------------------------------------------
     compas_rhino.draw_labels(labels,
@@ -290,7 +279,7 @@ def draw_volmesh_cells(volmesh,
         for hfkey in halffaces:
             hfkeys.append(hfkey)
 
-    volmesh.draw_faces(keys=hfkeys, color=hf_colordict)
+    volmesh.draw_faces(faces=hfkeys, color=hf_colordict)
 
 
 def draw_volmesh_face_normals(volmesh,
@@ -329,15 +318,15 @@ def draw_volmesh_face_normals(volmesh,
     # 2. normals to draw -------------------------------------------------------
     f_normals = []
     for hfkey in hfkeys:
-        center = volmesh.halfface_center(hfkey)
-        normal = scale_vector(volmesh.halfface_oriented_normal(hfkey), scale)
-        name   = '{}.edge.f_normal.{}'.format(volmesh.attributes['name'], hfkey)
+        center = volmesh.face_center(hfkey)
+        normal = scale_vector(volmesh.halfface_normal(hfkey), scale)
+        name = '{}.edge.f_normal.{}'.format(volmesh.attributes['name'], hfkey)
         f_normals.append({
             'start': center,
-            'end'  : add_vectors(center, normal),
+            'end': add_vectors(center, normal),
             'arrow': 'end',
             'color': hf_colordict[hfkey],
-            'name' : name})
+            'name': name})
 
     # 3. draw ------------------------------------------------------------------
     compas_rhino.draw_lines(f_normals,
@@ -358,8 +347,8 @@ def draw_volmesh_UD(volmesh,
 
     # 1. get colors ------------------------------------------------------------
     hf_color = (0, 0, 0)
-    prism_c  = (155, 225, 255)  # color for compression prisms
-    prism_t  = (255, 180, 180)  # color for tension prisms
+    prism_c = (155, 225, 255)  # color for compression prisms
+    prism_t = (255, 180, 180)  # color for tension prisms
 
     hf_colordict = color_to_colordict(color,
                                       hfkeys,
@@ -373,24 +362,24 @@ def draw_volmesh_UD(volmesh,
     # 3. halffaces and prisms --------------------------------------------------
     faces = []
     for hfkey in hfkeys:
-        vkeys  = volmesh.halfface[hfkey]
+        vkeys = volmesh.halfface[hfkey]
         hf_xyz = [halffaces[hfkey][i] for i in vkeys]
-        name   = '{}.face.ud.{}'.format(volmesh.name, hfkey)
+        name = '{}.face.ud.{}'.format(volmesh.name, hfkey)
         faces.append({'points': hf_xyz,
-                      'name'  : name,
-                      'color' : hf_colordict[hfkey]})
+                      'name': name,
+                      'color': hf_colordict[hfkey]})
 
     if draw_prisms:
         forces = get_force_mags(volmesh, network)
         for uv in prism_faces:
-            name  = '{}.face.ud.prism.{}'.format(volmesh.name, uv)
+            name = '{}.face.ud.prism.{}'.format(volmesh.name, uv)
             color = prism_c
             if forces[uv] > 0:
                 color = prism_t
             for face in prism_faces[uv]:
                 faces.append({'points': face,
-                              'name'  : name,
-                              'color' : color})
+                              'name': name,
+                              'color': color})
 
     # 4. draw ------------------------------------------------------------------
     compas_rhino.draw_faces(faces,
@@ -430,7 +419,7 @@ def draw_network_external_forces(volmesh,
 
     """
     # 2. get boundary hfs ------------------------------------------------------
-    hfkeys = volmesh.halffaces_on_boundary()
+    hfkeys = volmesh.halffaces_on_boundaries()
 
     # 1. delete any existing boundary forces -----------------------------------
     name = '*.edge.loads.*'
@@ -449,7 +438,7 @@ def draw_network_external_forces(volmesh,
         hfkeys = temp_hfs
 
     # 3. get hf areas and colors -----------------------------------------------
-    hf_areas  = {hfkey: volmesh.halfface_oriented_area(hfkey) for hfkey in hfkeys}
+    hf_areas = {hfkey: volmesh.halfface_area(hfkey) for hfkey in hfkeys}
 
     hf_c_dict = {}
     if gradient:
@@ -464,19 +453,19 @@ def draw_network_external_forces(volmesh,
     # 4. forces and labels to draw ---------------------------------------------
     lines = []
     for hfkey in hfkeys:
-        ckey   = volmesh.halfface_cell(hfkey)
-        normal = volmesh.halfface_oriented_normal(hfkey, unitized=False)
-        area   = hf_areas[hfkey],
+        ckey = volmesh.halfface_cell(hfkey)
+        normal = volmesh.halfface_normal(hfkey, unitized=False)
+        area = hf_areas[hfkey],
         vector = scale_vector(normal, scale)
-        sp     = network.vertex_coordinates(ckey)
-        ep     = add_vectors(sp, vector)
-        color  = colordict[hfkey]
+        sp = network.vertex_coordinates(ckey)
+        ep = add_vectors(sp, vector)
+        color = colordict[hfkey]
         lines.append({
             'start': sp,
-            'end'  : ep,
+            'end': ep,
             'color': color,
             'arrow': 'end',
-            'name' : '{}.edge.loads.{}.{}'.format(network.name, hfkey, area)})
+            'name': '{}.edge.loads.{}.{}'.format(network.name, hfkey, area)})
 
     # 5. draw ------------------------------------------------------------------
     compas_rhino.draw_lines(lines,
@@ -492,7 +481,7 @@ def draw_network_internal_forces(volmesh,
                                  scale=1.0):
 
     # 1. get vkeys -------------------------------------------------------------
-    vkeys = vkeys or network.vertex.keys()
+    vkeys = vkeys or network.nodes()
 
     # 2. colors and force magnitudes -------------------------------------------
     uv_f_dict = get_force_mags(volmesh, network)
@@ -502,10 +491,10 @@ def draw_network_internal_forces(volmesh,
     arrows = []
 
     for u in vkeys:
-        for v in network.vertex_neighbors(u):
+        for v in network.neighbors(u):
 
-            vec   = network.edge_direction(u, v)
-            u_xyz = network.vertex_coordinates(u)
+            vec = network.edge_direction(u, v)
+            u_xyz = network.node_coordinates(u)
 
             if (u, v) in uv_f_dict:
                 force = uv_f_dict[(u, v)]
@@ -519,17 +508,17 @@ def draw_network_internal_forces(volmesh,
 
             sp = u_xyz
             ep = v_xyz
-            if force < 0 :  # if compression
+            if force < 0:  # if compression
                 sp = v_xyz
                 ep = u_xyz
 
             arrows.append({
                 'start': sp,
-                'end'  : ep,
+                'end': ep,
                 'color': color,
                 'arrow': 'end',
                 'layer': network.layer,
-                'name' : '{}.edge.force.{}-{}'.format(network.name, u, v)})
+                'name': '{}.edge.force.{}-{}'.format(network.name, u, v)})
 
     # 4. draw force vectors ----------------------------------------------------
     compas_rhino.draw_lines(arrows)
@@ -553,12 +542,12 @@ def draw_network_pipes(volmesh,
     cylinders = []
     for uv in network.edges():
         cylinders.append({
-            'start' : network.vertex_coordinates(uv[0]),
-            'end'   : network.vertex_coordinates(uv[1]),
-            'radius': volmesh.halfface_oriented_area(uv_hf_dict[uv]) * scale,
-            'color' : colordict[uv],
-            'layer' : network.layer,
-            'name'  : '{}.edge.pipes.{}'.format(network.name, uv)})
+            'start': network.vertex_coordinates(uv[0]),
+            'end': network.vertex_coordinates(uv[1]),
+            'radius': volmesh.halfface_area(uv_hf_dict[uv]) * scale,
+            'color': colordict[uv],
+            'layer': network.layer,
+            'name': '{}.edge.pipes.{}'.format(network.name, uv)})
 
     # 4. draw ------------------------------------------------------------------
     compas_rhino.draw_cylinders(cylinders, cap=True)
@@ -589,7 +578,7 @@ def draw_corresponding_elements(volmesh,
 
     volmesh.clear()
     volmesh.draw_edges()
-    volmesh.draw_faces(keys=faces_to_draw, color=hf_c_dict)
+    volmesh.draw_faces(faces=faces_to_draw, color=hf_c_dict)
 
     datastructure.clear()
     datastructure.draw_edges(color=uv_c_dict)
@@ -607,7 +596,7 @@ def draw_compression_tension(volmesh,
 
     volmesh.clear()
     volmesh.draw_edges()
-    volmesh.draw_faces(keys=hfkeys, color=hf_c_dict)
+    volmesh.draw_faces(faces=hfkeys, color=hf_c_dict)
 
     network.clear()
     network.draw_edges(color=uv_c_dict)
@@ -615,8 +604,8 @@ def draw_compression_tension(volmesh,
     # draw labels --------------------------------------------------------------
     if label:
         text_dict = {fkey: str(fkey) for fkey in hfkeys}
-        volmesh.draw_face_labels(text=text_dict, color=hf_c_dict)
-        network.draw_edge_labels(color=uv_c_dict)
+        volmesh.draw_facelabels(text=text_dict, color=hf_c_dict)
+        network.draw_edgelabels(color=uv_c_dict)
 
 
 def draw_directed_uv(datastructure,
@@ -624,15 +613,18 @@ def draw_directed_uv(datastructure,
 
     edges = []
     for u, v in datastructure.edges():
+
+        sp = datastructure.vertex_coordinates(u)
+        ep = datastructure.vertex_coordinates(v)
+
         edges.append({
-            'start': datastructure.vertex_coordinates(u),
-            'end'  : datastructure.vertex_coordinates(v),
+            'start': sp,
+            'end': ep,
             'arrow': 'end',
             'color': uv_color[(u, v)],
-            'name' : '{}.edge.{}-{}'.format(datastructure.name, u, v)})
+            'name': '{}.edge.{}-{}'.format(datastructure.name, u, v)})
 
     # 3. draw network ----------------------------------------------------------
-    datastructure.clear_edges()
     compas_rhino.draw_lines(edges,
                             layer=datastructure.layer,
                             clear=False,
@@ -660,7 +652,7 @@ def draw_directed_hf_and_uv(volmesh,
     draw_directed_uv(datastructure, uv_color=uv_colordict)
 
     # 4. draw volmesh ----------------------------------------------------------
-    volmesh.draw_faces(keys=hfkeys, color=hf_colordict)
+    volmesh.draw_faces(faces=hfkeys, color=hf_colordict)
     draw_volmesh_face_normals(volmesh,
                               hfkeys,
                               color=hf_colordict,
@@ -684,37 +676,37 @@ def draw_egi_arcs(egi):
     for u, v in egi.edges():
         normal_1 = subtract_vectors(egi.vertex_coordinates(u), origin)
         normal_2 = subtract_vectors(egi.vertex_coordinates(v), origin)
-        arc      = draw_arc(normal_1, normal_2, origin)
-        guid     = add_curve(arc)
-        obj      = find_object(guid)
-        color    = (0, 0, 0)
+        arc = draw_arc(normal_1, normal_2, origin)
+        guid = add_curve(arc)
+        obj = find_object(guid)
+        color = (0, 0, 0)
         if egi.vertex[u]['type'] == 'zero' or egi.vertex[v]['type'] == 'zero':
             color = (255, 0, 0)
-        attr                  = obj.Attributes
-        attr.Name             = egi.edge_name(u, v)
-        attr.ObjectColor      = FromArgb(*color)
-        attr.ColorSource      = ColorFromObject
+        attr = obj.Attributes
+        attr.Name = egi.edge_name(u, v)
+        attr.ObjectColor = FromArgb(*color)
+        attr.ColorSource = ColorFromObject
         attr.ObjectDecoration = EndArrowhead
         obj.CommitChanges()
 
 
 def bake_cells_as_polysurfaces(volmesh):
-    for ckey in volmesh.cell:
+    for ckey in volmesh.cells():
         origin = volmesh.cell_centroid(ckey)
-        ball   = Sphere(Point3d(*tuple(origin)), 100)
-        brep   = Brep.CreateFromSphere(ball)
+        ball = Sphere(Point3d(*tuple(origin)), 100)
+        brep = Brep.CreateFromSphere(ball)
         rs.EnableRedraw(False)
-        for hfkey in volmesh.cell_halffaces(ckey):
+        for hfkey in volmesh.cell_faces(ckey):
             center = volmesh.halfface_center(hfkey)
-            normal = volmesh.halfface_oriented_normal(hfkey)
-            plane  = Plane(Point3d(*tuple(center)), Vector3d(*tuple(normal)))
+            normal = volmesh.halfface_normal(hfkey)
+            plane = Plane(Point3d(*tuple(center)), Vector3d(*tuple(normal)))
             intersection = brep.Trim(plane, 0.1)
             if intersection:
                 brep = brep.Trim(plane, 0.0001)[0]
                 brep = brep.CapPlanarHoles(0.0001)
-        guid  = add_brep(brep)
-        obj   = find_object(guid)
-        attr  = obj.Attributes
+        guid = add_brep(brep)
+        obj = find_object(guid)
+        attr = obj.Attributes
         layer = 'cells_as_polysurfaces'
         rs.AddLayer(layer)
         index = find_layer_by_fullpath(layer, True)
@@ -726,9 +718,9 @@ def bake_cells_as_polysurfaces(volmesh):
 
 def draw_arc(normal_1, normal_2, origin):
     mid_pt = normalize_vector(add_vectors(normal_1, normal_2))
-    arc    = Arc(Point3d(*[sum(axis) for axis in zip(normal_1, origin)]),
-                 Point3d(*[sum(axis) for axis in zip(mid_pt, origin)]),
-                 Point3d(*[sum(axis) for axis in zip(normal_2, origin)]))
+    arc = Arc(Point3d(*[sum(axis) for axis in zip(normal_1, origin)]),
+              Point3d(*[sum(axis) for axis in zip(mid_pt, origin)]),
+              Point3d(*[sum(axis) for axis in zip(normal_2, origin)]))
     arc_as_curve = ArcCurve(arc)
     return arc_as_curve
 
